'' ILI9325 driver using pins P0-P11 for the display and P16-P23 for the touchscreen
'' James Moxham 2011

CON


  _clkmode      = xtal1 + pll16x                        ' use crystal x 16
  _xinfreq      = 5_000_000

  _cardDataOutPin = 12                                  ' SD card pins
  _cardClockPin = 13
  _cardDataInPin = 14
  _cardChipSelectPin = 15

  _clockDataPin = 29                                    ' clock not used but need to include this
  _clockClockPin = 28

  _TV_Enabled = true ' TV display on
  _TV_Pin = 16 ' group of 3 pins starting at pin 16

OBJ
 delay    : "timing"
 fat: "SD2.0_FATEngine.spin"            ' thanks to Kye
 text: "tv_text"
 str: "ASCII0_STREngine.spin"     
  
VAR
     long DisplayPins ' status of all the display pins

PUB Start | i,j

  text.start(_TV_Pin)                                 ' start the TV driver
  PrintStringCR(string("Testing for SD card"))          ' helpful message if card is out, better than just a blank screen  

  ifnot(fat.FATEngineStart(_cardDataOutPin, _cardClockPin, _cardDataInPin, _cardChipSelectPin, _clockDataPin, _clockClockPin))
    reboot
  fat.mountPartition(0,0)     ' mount the sd card

    DisplayPins := %00000000_00000000_00000000_00000000 ' store the status of the display pins
    EnableLatchPins
    'latch5(255)                                           ' D0-D7 high   for debugging
    'latch6(255)                                           ' D8-D15 high
    'Latch7                                              ' RS/CS/WR/RD/RESET all low
    Init                                                ' start up the driver
    
    ChipSelectLow                                       ' talk to the chip

    fat.openfile(string("lunch.ili"),"R")      ' 240x320
    'fat.readdata(pix.displaypointer,19200)   ' read in a block if enough hub ram
    Address_set(0,0,239,319)      ' whole screen
    repeat 76800
       'PrintDecimal(fat.readbyte)                      ' debugging
       Lcd_Write_Data(fat.readbyte,fat.readbyte) ' high byte stored first
      
    fat.closefile   
    
    'Address_set(40,40,40,140)   ' fill up in this block x1,y1 to x2,y2
    'repeat 100
    '   Lcd_Write_Data(%11111111,%11111111)    ' white line
    
    {
    Address_set(100,0,129,29)   ' fill up in this block x1,y1 to x2,y2
    repeat 900
       Lcd_Write_Data(%11111000,%00000000)
    Address_set(140,0,169,29)   ' fill up in this block x1,y1 to x2,y2
    repeat 900
       Lcd_Write_Data(%00000111,%11100000) 

    Address_set(180,0,209,29)   ' fill up in this block x1,y1 to x2,y2
    repeat 900
       Lcd_Write_Data(%00000000,%00011111) 
       
    Address_set(0,0,29,29)   ' fill up in this block x1,y1 to x2,y2
    repeat 900
      'Lcd_Write_Data(%00000111,%11100000)    ' fills up this block with data bytes RRRRRGGGGGGBBBBB 5 red 6 green 5 blue
      Lcd_Write_Data(%11111111,%11111111)    ' fills up this block with data bytes RRRRRGGGGGGBBBBB 5 red 6 green 5 blue    

    Address_set(40,0,69,29)   ' fill up in this block x1,y1 to x2,y2
    repeat 900
       Lcd_Write_Data(%11111111,%11100000) 

    Address_set(100,100,131,150)   ' fill up in this block x1,y1 to x2,y2   
    i := 0
    repeat 50
      repeat 32
        Lcd_Write_Data(i,j)
        j := j+1
      j :=0  

    Address_set(0,0,239,319)      ' whole screen
    repeat 76800
       i+=1
       i := i & %00000000_00000000_00000000_11111111 ' mask to a byte
       if i == 0
         j+=1
       j := j & %00000000_00000000_00000000_11111111 ' mask to a byte     
       Lcd_Write_Data(j,i)
     }
    ChipSelectHigh        
PRI Init ' see LCD.c program in c:\propeller\ILI9325\Updated c51 code
    ResetHigh
    delay.pause1ms(5)
    ResetLow
    delay.pause1ms(5)
    ResetHigh
    ChipSelectHigh
    ReadHigh
    WriteHigh
    delay.pause1ms(5)
    ChipSelectLow
          ' ************* Start Initial Sequence **********
    Lcd_Write_Com($00,$E5)
    Lcd_Write_Data($78,$F0)                               ' set SRAM internal timing
    Lcd_Write_Com($00,$01)
    Lcd_Write_Data($01,$00)                             ' set SS and SM bit
    Lcd_Write_Com($00,$02)
    Lcd_Write_Data($07,$00)                             ' set 1 line inversion
    Lcd_Write_Com($00,$03)
    Lcd_Write_Data($10,$30)                             ' set GRAM write direction and BGR=1.
    Lcd_Write_Com($00,$04)
    Lcd_Write_Data($00,$00)                             ' Resize register
    Lcd_Write_Com($00,$08)
    Lcd_Write_Data($02,$07)                             ' set the back porch and front porch
    Lcd_Write_Com($00,$09)
    Lcd_Write_Data($00,$00)                             ' set non-display area refresh cycle ISC[3:0]
    Lcd_Write_Com($00,$0A)
    Lcd_Write_Data($00,$00)                             ' FMARK function
    Lcd_Write_Com($00,$0C)
    Lcd_Write_Data($00,$00)                             ' RGB interface setting
    Lcd_Write_Com($00,$0D)
    Lcd_Write_Data($00,$00)                             ' Frame marker Position
    Lcd_Write_Com($00,$0F)
    Lcd_Write_Data($00,$00)                             ' RGB interface polarity
'        *************Power On sequence ****************//
    Lcd_Write_Com($00,$10)
    Lcd_Write_Data($00,$00)                             ' SAP, BT[3:0], AP, DSTB, SLP, STB
    Lcd_Write_Com($00,$11)
    Lcd_Write_Data($00,$07)                             ' DC1[2:0], DC0[2:0], VC[2:0]
    Lcd_Write_Com($00,$12)
    Lcd_Write_Data($00,$00)                             ' VREG1OUT voltage
    Lcd_Write_Com($00,$13)
    Lcd_Write_Data($00,$00)                             ' VDV[4:0] for VCOM amplitude
    Lcd_Write_Com($00,$07)
    Lcd_Write_Data($00,$01)
    delay.pause1ms(50)                                  ' Dis-charge capacitor power voltage
    Lcd_Write_Com($00,$10)
    Lcd_Write_Data($10,$90)                             ' 1490//SAP, BT[3:0], AP, DSTB, SLP, STB
    Lcd_Write_Com($00,$11)
    Lcd_Write_Data($02,$27)                             ' DC1[2:0], DC0[2:0], VC[2:0]
    delay.pause1ms(50)                                  ' delay
    Lcd_Write_Com($00,$12)
    Lcd_Write_Data($00,$1F)                             '001C// Internal reference voltage= Vci;
    delay.pause1ms(50)                                  ' delay   
    Lcd_Write_Com($00,$13)
    Lcd_Write_Data($15,$00)                             '$1000//1400   Set VDV[4:0] for VCOM amplitude  1A00
    Lcd_Write_Com($00,$29)
    Lcd_Write_Data($00,$27)                             '$0012 //001a  Set VCM[5:0] for VCOMH  //$0025  0034
    Lcd_Write_Com($00,$2B)
    Lcd_Write_Data($00,$0D)                             ' Set Frame Rate   000C
    delay.pause1ms(50)                                  ' delay   
    Lcd_Write_Com($00,$20)
    Lcd_Write_Data($00,$00)                             ' GRAM horizontal Address
    Lcd_Write_Com($00,$21)
    Lcd_Write_Data($00,$00)                             ' GRAM Vertical Address
'         ----------- Adjust the Gamma Curve ----------//
    Lcd_Write_Com($00,$30)
    Lcd_Write_Data($00,$00)
    Lcd_Write_Com($00,$31)
    Lcd_Write_Data($07,$07)
    Lcd_Write_Com($00,$32)
    Lcd_Write_Data($03,$07)
    Lcd_Write_Com($00,$35)
    Lcd_Write_Data($02,$00)
    Lcd_Write_Com($00,$36)
    Lcd_Write_Data($00,$08)                           '//0207
    Lcd_Write_Com($00,$37)
    Lcd_Write_Data($00,$04)                           '//0306
    Lcd_Write_Com($00,$38)
    Lcd_Write_Data($00,$00)                           '//0102
    Lcd_Write_Com($00,$39)
    Lcd_Write_Data($07,$07)                           '//0707
    Lcd_Write_Com($00,$3C)
    Lcd_Write_Data($00,$02)                           '//0702
    Lcd_Write_Com($00,$3D)
    Lcd_Write_Data($1D,$04)                           '//1604
'        ------------------ Set GRAM area ---------------//
    Lcd_Write_Com($00,$50)
    Lcd_Write_Data($00,$00)     ' Horizontal GRAM Start Address
    Lcd_Write_Com($00,$51)
    Lcd_Write_Data($00,$EF)     ' Horizontal GRAM End Address
    Lcd_Write_Com($00,$52)
    Lcd_Write_Data($00,$00)     ' Vertical GRAM Start Address
    Lcd_Write_Com($00,$53)
    Lcd_Write_Data($01,$3F)     ' Vertical GRAM Start Address
    Lcd_Write_Com($00,$60)
    Lcd_Write_Data($A7,$00)     ' Gate Scan Line
    Lcd_Write_Com($00,$61)
    Lcd_Write_Data($00,$01)     ' NDL,VLE, REV
    Lcd_Write_Com($00,$6A)
    Lcd_Write_Data($00,$00)     ' set scrolling line
'        -------------- Partial Display Control ---------/

    Lcd_Write_Com($00,$80)
    Lcd_Write_Data($00,$00)
    Lcd_Write_Com($00,$81)
    Lcd_Write_Data($00,$00)
    Lcd_Write_Com($00,$82)
    Lcd_Write_Data($00,$00)
    Lcd_Write_Com($00,$83)
    Lcd_Write_Data($00,$00)
    Lcd_Write_Com($00,$84)
    Lcd_Write_Data($00,$00)
    Lcd_Write_Com($00,$85)
    Lcd_Write_Data($00,$00)
'        //-------------- Panel Control -------------------//
    Lcd_Write_Com($00,$90)
    Lcd_Write_Data($00,$10)
    Lcd_Write_Com($00,$92)
    Lcd_Write_Data($06,$00)
    Lcd_Write_Com($00,$07)
    Lcd_Write_Data($01,$33)     ' 262K color and display ON

    ChipSelectHigh

PRI LCD_Writ_Bus(VH,VL) 
    Latch5(VL)                                          ' send low byte
    Latch6(VH)                                          ' send high byte
    WriteLow                                            ' write pin low
    WriteHigh                                           ' toggle write pin

PRI Lcd_Write_Com(VH,VL)
    RSLow
    LCD_Writ_Bus(VH,VL)

PRI Lcd_Write_Data(VH,VL)
    RSHigh
    LCD_Writ_Bus(VH,VL)


PRI EnableLatchPins
    DIRA:=%00000000_00000000_00001111_11111111 ' 138 active, gate active and 8 data lines active    
PRI Tristate ' tristate all pins - needs a pullup on the 138 enable prop pin P8
    DIRA:=%00000000_00000000_00000000_00000000     
PRI ToggleGate
   OUTA[8]:=0                                            ' set gate pin low
   OUTA[8]:=1                                            ' and high again - may need a delay in PASM

PRI Latch5(VL)                                          ' send the low byte xxxx = C,B,A,enable
   VL := VL | %00000000_00000000_00001011_00000000      ' OR with the LCD address  101
   OUTA := VL                                            ' 4 send it to propeller pins
   ToggleGate                                           ' 5 and latch it to the latch

PRI Latch6(VH)                                          ' send the middle byte 
   VH := VH | %00000000_00000000_00001101_00000000        ' 3 OR with the LCD address for latch 6  110
   OUTA := VH                                              ' 4 send it to propeller pins
   ToggleGate                                           ' 5 and latch it to the latch

PRI Latch7 | i                                          ' send the high byte if DisplayPins to the approprite latch
   i := DisplayPins                                     ' get the value                                         
   i := i >> 16                                         ' shift right by 16 places 
   i := i & %11111111                                   ' mask the low byte
   i := i | %00000000_00000000_00001111_00000000        ' 3 OR with the LCD address for latch 7    111
   OUTA := i                                            ' 4 send it to propeller pins
   ToggleGate                                           ' 5 and latch it to the latch

PRI RSLow                                    ' RS pin
    DisplayPins := DisplayPins & %11111111_11111110_11111111_11111111      ' mask the reset pin to zero 
    Latch7                                              ' send to the latch

PRI RSHigh
    DisplayPins := DisplayPins | %00000000_00000001_00000000_00000000      ' mask the reset pin to 1 
    Latch7                                              ' send to the latch

PRI WriteLow                                    
    DisplayPins := DisplayPins & %11111111_11111101_11111111_11111111      ' mask the reset pin to zero 
    Latch7                                              ' send to the latch

PRI WriteHigh
    DisplayPins := DisplayPins | %00000000_00000010_00000000_00000000      ' mask the reset pin to 1 
    Latch7                                              ' send to the latch

PRI ReadLow                                    
    DisplayPins := DisplayPins & %11111111_11111011_11111111_11111111      ' mask the reset pin to zero 
    Latch7                                              ' send to the latch

PRI ReadHigh
    DisplayPins := DisplayPins | %00000000_00000100_00000000_00000000      ' mask the reset pin to 1 
    Latch7    

PRI ChipSelectLow                                    
    DisplayPins := DisplayPins & %11111111_11110111_11111111_11111111      ' mask the reset pin to zero 
    Latch7                                              ' send to the latch

PRI ChipSelectHigh
    DisplayPins := DisplayPins | %00000000_00001000_00000000_00000000      ' mask the reset pin to 1 
    Latch7

PRI ResetLow                                    
    DisplayPins := DisplayPins & %11111111_11101111_11111111_11111111      ' mask the reset pin to zero 
    Latch7                                              ' send to the latch

PRI ResetHigh
    DisplayPins := DisplayPins | %00000000_00010000_00000000_00000000      ' mask the reset pin to 1 
    Latch7

PRI Address_set(x1, y1, x2, y2) 
    Lcd_Write_Com($00,$20)
    Lcd_Write_Data(x1>>8,x1)
    Lcd_Write_Com($00,$21)
    Lcd_Write_Data(y1>>8,y1)
    Lcd_Write_Com($00,$50)
    Lcd_Write_Data(x1>>8,x1)
    Lcd_Write_Com($00,$52)
    Lcd_Write_Data(y1>>8,y1)
    Lcd_Write_Com($00,$51)
    Lcd_Write_Data(x2>>8,x2)
    Lcd_Write_Com($00,$53)
    Lcd_Write_Data(y2>>8,y2)
    Lcd_Write_Com($00,$22)                                                  

PRI Pant(VH,VL)
    ChipSelectLow
    Address_set(0,0,240,320)
    Lcd_Write_Data(VH,VL)
    ChipSelectHigh


PUB PrintStringCR(pstring)' sends pstring to the vga and serial port
     PrintString(pstring)                               ' print the string  
     crlf

PUB PrintString(pstring)' sends pstring to the vga and serial port with no CRLF
    if (_TV_Enabled)
      text.str(pstring)
'    if (_VGA_Enabled)  
'      vt100.str(pstring)                                 ' send to vga screen
'    if (_Serial_Enabled)   
'    sio.str(0,pstring)                                 ' send to com port
'    if (_lcd_Enabled)
'       lcd.str(pstring)                                   ' send to 20x4 lCD display

PUB PrintChar(c) ' sends c to vga and serial port
    if (_TV_Enabled)
      text.out(c)
'    if (_VGA_Enabled)
'      vt100.out(c)                                        ' send to vga
'    if (_Serial_Enabled)
'      sio.tx(0,c)                                         ' send to com port
'    if (_lcd_Enabled)
'      LCD.out(c)                                          ' send to LCD display      
PUB CRLF
    PrintChar(13)                                        ' send to vga
    PrintChar(10)                                        ' send to vga

PUB PrintDecimal(number)                                ' print the decimal value, useful for debuggin
     PrintString(str.integerToDecimal(number, 10))      
     crlf
            
{
#include <reg51.h>

/* http://ttmcu.taobao.com ͤ
Ի:JME-2İ+1TָڵSTCƬ51ںSTC12LE5A60S2)+33M      Ƭѹ3.3V
ĬIOӷʽ
ߣRS-P3^5;    WR-P3^6;   RD-P3^7;   CS-P1^0;   REST-P1^2;
: DB0-DB7P0^0-P0^7;  DB8-DB15P2^0-P2^7;8λģʽDB0-DB7Բӣ
ӷʽ(ʹôɲ)
D_CLK-P1^7;  D_CS-P1^4;  D_DIN-P3^0;  D_OUT-P3^1;  D_PENIRQ-P3^4;
*/
#define Bus_16        //16λģʽ,ʹ8λģʽעʹ䣬ʹ16λģʽ򿪴˾
#define  LCD_DataPortH P2     //8λݿ,8λģʽֻʹø8λ 
#define  LCD_DataPortL P0     //8λݿ     ,8λģʽµ8λԲ,ȷP0Ѿ10K,̫СС4.7K,Ƽ10K.
sbit LCD_RS = P3^5;              ///л
sbit LCD_WR = P3^6;               //д
sbit LCD_RD =P3^7;                   //
sbit LCD_CS=P1^0;               //Ƭѡ  
sbit LCD_REST = P1^2;         //λ   

void delayms(int count)  // /* X1ms */
{
        int i,j;
        for(i=0;i<count;i++)
                for(j=0;j<100;j++);
}

#ifdef  Bus_16    //-16λģʽ   
void LCD_Writ_Bus(char VH,char VL)   //д뺯
{
    LCD_DataPortH=VH;   
        LCD_DataPortL=VL;               
        LCD_WR=0;
        LCD_WR=1; 
}
#else                   //-8λģʽ 
void LCD_Writ_Bus(char VH,char VL)   //д뺯
{       
    LCD_DataPortH=VH;   
        LCD_WR=0;
        LCD_WR=1;
        LCD_DataPortH=VL;               
        LCD_WR=0;
        LCD_WR=1;
}
#endif

void Lcd_Write_Com(char VH,char VL)      //
{       
    LCD_RS=0;
        LCD_Writ_Bus(VH,VL);
}


void Lcd_Write_Data(char VH,char VL)    //
{
    LCD_RS=1;
        LCD_Writ_Bus(VH,VL);
}

void Address_set(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2)
{
        Lcd_Write_Com(0x00,0x20);Lcd_Write_Data(x1>>8,x1);        //Xλ
    Lcd_Write_Com(0x00,0x21);Lcd_Write_Data(y1>>8,y1);   //Yλ
    Lcd_Write_Com(0x00,0x50);Lcd_Write_Data(x1>>8,x1);   //ʼX
        Lcd_Write_Com(0x00,0x52);Lcd_Write_Data(y1>>8,y1);        //ʼY
    Lcd_Write_Com(0x00,0x51);Lcd_Write_Data(x2>>8,x2);   //X
        Lcd_Write_Com(0x00,0x53);Lcd_Write_Data(y2>>8,y2);   //Y
    Lcd_Write_Com(0x00,0x22);                                                    
}

void Lcd_Init(void)
{                               
    LCD_REST=1;
    delayms(5); 
        LCD_REST=0;
        delayms(5);
        LCD_REST=1;
        LCD_CS=1;
        LCD_RD=1;
        LCD_WR=1;
        delayms(5);

        LCD_CS =0;  //Ƭѡʹ
        //************* Start Initial Sequence **********//
        Lcd_Write_Com(0x00,0xE5); Lcd_Write_Data(0x78,0xF0); // set SRAM internal timing
        Lcd_Write_Com(0x00,0x01); Lcd_Write_Data(0x01,0x00); // set SS and SM bit
        Lcd_Write_Com(0x00,0x02); Lcd_Write_Data(0x07,0x00); // set 1 line inversion
        Lcd_Write_Com(0x00,0x03); Lcd_Write_Data(0x10,0x30); // set GRAM write direction and BGR=1.
        Lcd_Write_Com(0x00,0x04); Lcd_Write_Data(0x00,0x00); // Resize register
        Lcd_Write_Com(0x00,0x08); Lcd_Write_Data(0x02,0x07); // set the back porch and front porch
        Lcd_Write_Com(0x00,0x09); Lcd_Write_Data(0x00,0x00); // set non-display area refresh cycle ISC[3:0]
        Lcd_Write_Com(0x00,0x0A); Lcd_Write_Data(0x00,0x00); // FMARK function
        Lcd_Write_Com(0x00,0x0C); Lcd_Write_Data(0x00,0x00); // RGB interface setting
        Lcd_Write_Com(0x00,0x0D); Lcd_Write_Data(0x00,0x00); // Frame marker Position
        Lcd_Write_Com(0x00,0x0F); Lcd_Write_Data(0x00,0x00); // RGB interface polarity
        //*************Power On sequence ****************//
        Lcd_Write_Com(0x00,0x10); Lcd_Write_Data(0x00,0x00); // SAP, BT[3:0], AP, DSTB, SLP, STB
        Lcd_Write_Com(0x00,0x11); Lcd_Write_Data(0x00,0x07); // DC1[2:0], DC0[2:0], VC[2:0]
        Lcd_Write_Com(0x00,0x12); Lcd_Write_Data(0x00,0x00); // VREG1OUT voltage
        Lcd_Write_Com(0x00,0x13); Lcd_Write_Data(0x00,0x00); // VDV[4:0] for VCOM amplitude
        Lcd_Write_Com(0x00,0x07); Lcd_Write_Data(0x00,0x01);
        delayms(50); // Dis-charge capacitor power voltage
        Lcd_Write_Com(0x00,0x10); Lcd_Write_Data(0x10,0x90); // 1490//SAP, BT[3:0], AP, DSTB, SLP, STB
        Lcd_Write_Com(0x00,0x11); Lcd_Write_Data(0x02,0x27); // DC1[2:0], DC0[2:0], VC[2:0]
        delayms(50); // Delay 50ms
        Lcd_Write_Com(0x00,0x12); Lcd_Write_Data(0x00,0x1F); //001C// Internal reference voltage= Vci;
        delayms(50); // Delay 50ms
        Lcd_Write_Com(0x00,0x13); Lcd_Write_Data(0x15,0x00); //0x1000//1400   Set VDV[4:0] for VCOM amplitude  1A00
        Lcd_Write_Com(0x00,0x29); Lcd_Write_Data(0x00,0x27); //0x0012 //001a  Set VCM[5:0] for VCOMH  //0x0025  0034
        Lcd_Write_Com(0x00,0x2B); Lcd_Write_Data(0x00,0x0D); // Set Frame Rate   000C
        delayms(50); // Delay 50ms
        Lcd_Write_Com(0x00,0x20); Lcd_Write_Data(0x00,0x00); // GRAM horizontal Address
        Lcd_Write_Com(0x00,0x21); Lcd_Write_Data(0x00,0x00); // GRAM Vertical Address
        // ----------- Adjust the Gamma Curve ----------//
        Lcd_Write_Com(0x00,0x30); Lcd_Write_Data(0x00,0x00);
        Lcd_Write_Com(0x00,0x31); Lcd_Write_Data(0x07,0x07);
        Lcd_Write_Com(0x00,0x32); Lcd_Write_Data(0x03,0x07);
        Lcd_Write_Com(0x00,0x35); Lcd_Write_Data(0x02,0x00);
        Lcd_Write_Com(0x00,0x36); Lcd_Write_Data(0x00,0x08);//0207
        Lcd_Write_Com(0x00,0x37); Lcd_Write_Data(0x00,0x04);//0306
        Lcd_Write_Com(0x00,0x38); Lcd_Write_Data(0x00,0x00);//0102
        Lcd_Write_Com(0x00,0x39); Lcd_Write_Data(0x07,0x07);//0707
        Lcd_Write_Com(0x00,0x3C); Lcd_Write_Data(0x00,0x02);//0702
        Lcd_Write_Com(0x00,0x3D); Lcd_Write_Data(0x1D,0x04);//1604
        
        //------------------ Set GRAM area ---------------//
        Lcd_Write_Com(0x00,0x50); Lcd_Write_Data(0x00,0x00); // Horizontal GRAM Start Address
        Lcd_Write_Com(0x00,0x51); Lcd_Write_Data(0x00,0xEF); // Horizontal GRAM End Address
        Lcd_Write_Com(0x00,0x52); Lcd_Write_Data(0x00,0x00); // Vertical GRAM Start Address
        Lcd_Write_Com(0x00,0x53); Lcd_Write_Data(0x01,0x3F); // Vertical GRAM Start Address
        Lcd_Write_Com(0x00,0x60); Lcd_Write_Data(0xA7,0x00); // Gate Scan Line
        Lcd_Write_Com(0x00,0x61); Lcd_Write_Data(0x00,0x01); // NDL,VLE, REV
        Lcd_Write_Com(0x00,0x6A); Lcd_Write_Data(0x00,0x00); // set scrolling line
        //-------------- Partial Display Control ---------//
        Lcd_Write_Com(0x00,0x80); Lcd_Write_Data(0x00,0x00);
        Lcd_Write_Com(0x00,0x81); Lcd_Write_Data(0x00,0x00);
        Lcd_Write_Com(0x00,0x82); Lcd_Write_Data(0x00,0x00);
        Lcd_Write_Com(0x00,0x83); Lcd_Write_Data(0x00,0x00);
        Lcd_Write_Com(0x00,0x84); Lcd_Write_Data(0x00,0x00);
        Lcd_Write_Com(0x00,0x85); Lcd_Write_Data(0x00,0x00);
        //-------------- Panel Control -------------------//
        Lcd_Write_Com(0x00,0x90); Lcd_Write_Data(0x00,0x10);
        Lcd_Write_Com(0x00,0x92); Lcd_Write_Data(0x06,0x00);
        Lcd_Write_Com(0x00,0x07); Lcd_Write_Data(0x01,0x33); // 262K color and display ON
        LCD_CS =1;  //رƬѡʹ

}

void Pant(char VH,char VL)
{
        int i,j;
        LCD_CS =0;  //Ƭѡʹ
        Address_set(0,0,240,320);
    for(i=0;i<320;i++)
         {
          for (j=0;j<240;j++)
                {
                 Lcd_Write_Data(VH,VL);
            }

          }
     LCD_CS =1;  //رƬѡʹ
}

main()
{ 
        Lcd_Init();          //TFTʼ
        Pant(0xff,0xff);         //TFT      
        while(1)
        {
            Pant(0xf8,0x00); //ɫ
                delayms(2000);
            Pant(0X07,0xE0); //ɫ
                delayms(2000);
            Pant(0x00,0x1f); //ɫ                      
        delayms(2000);
    }



}
}    